@@ -130,8 +130,8 @@ def lin(a,key):
     print("unsuccessfull")  
 
 
-def max_min(A,i,j,max,min):
-  max=min=A[i]
+def max_min(A):
+  max=min=A[0]
   n=len(A)
   for i in range(0,n):
     if(A[i]>max):
